@@ -247,9 +247,11 @@
 #' plot(sam, scale_range = TRUE, low_pass_size = 5)
 #' plot(sam, scale_range = TRUE, low_pass_size = 10)
 #'     
+#' \dontrun{## legacy transform functions from suuzhet
 #' plot(sam, transformation.function = syuzhet::get_transformed_values)
 #' plot(sam, transformation.function = syuzhet::get_transformed_values,  
 #'     scale_range = TRUE, low_pass_size = 5)
+#' }
 #' 
 #' y <- get_sentences(
 #'     "He was not the sort of man that one would describe as especially handsome."
@@ -324,7 +326,7 @@ sentiment.get_sentences_character <- function(text.var, polarity_dt = lexicon::h
     valence_shifters_dt = lexicon::hash_valence_shifters, hyphen = "",
     amplifier.weight = .8, n.before = 5, n.after = 2, question.weight = 1,
     adversative.weight = .25, neutral.nonverb.like = FALSE, missing_value = 0, ...){
-    
+
     sentences <- id2 <- pol_loc <- comma_loc <- P <- non_pol <- lens <-
             cluster_tag <- w_neg <- neg <- A <- a <- D <- d <- wc <- id <-
             T_sum <- N <- . <- b <- before <- NULL
@@ -350,7 +352,7 @@ sentiment.get_sentences_character <- function(text.var, polarity_dt = lexicon::h
     #     buts <- paste0('(', paste(buts, collapse = '|'), ')')
     #     sent_dat[, sentences := gsub(buts, ', \\1', sentences, ignore.case = TRUE, perl = TRUE)][]
     # }
-# browser() 
+
     ## replace like when preposition
     if (neutral.nonverb.like && 'like' %in% polarity_dt[[1]]) {
        
@@ -362,9 +364,9 @@ sentiment.get_sentences_character <- function(text.var, polarity_dt = lexicon::h
             )
         ][]
     }
-# browser()    
+ 
     # space fill (~~), break into words    
-    sent_dat[, 'words' := list(make_words(space_fill(sentences, space_words), hyphen = hyphen))]
+    sent_dat[, 'words' := list(make_words(space_fill_senti(sentences, space_words), hyphen = hyphen))]
 
     # make sentence id for each row id
     sent_dat[, id2:=seq_len(.N), by='id']
@@ -572,7 +574,15 @@ replace_na <- function(x, y = 0) {x[is.na(x)] <- y; x}
 #' @export
 plot.sentiment <- function(x, transformation.function = syuzhet::get_dct_transform, ...){
 
-    m <- transformation.function(stats::na.omit(x[["sentiment"]]), ...)
+    x <- stats::na.omit(x[["sentiment"]])
+    
+    if (length(x) < 3) stop('Output contains less than 3 observations.  Cannot plot n < 3', call. = FALSE)
+    
+    if (length(x) < 100 && isTRUE(all.equal(syuzhet::get_dct_transform, transformation.function))) {
+        x <- stats::approx(x = seq_along(x), y = x, n = 100)[['y']]
+    }    
+    
+    m <- transformation.function(x, ...)
 
     dat <- data.frame(
         Emotional_Valence = m,
